@@ -22,11 +22,12 @@ def iir_notch(notch_freq, fs, Q=30):
 
 def applyButter(sample, highPass, lowPass, notchFilter):
     filtered = sample
-    if lowPass is not None:  # Low pass
-        filtered = lfilter(lowPass[0], lowPass[1], filtered)
-    if highPass is not None:
-        filtered = lfilter(notchFilter[0], notchFilter[1], filtered)
-    if notchFilter is not None:
-        filtered = lfilter(highPass[0], highPass[1], filtered)
+    for channel in range(sample.sape[1]):
+        if lowPass is not None:  # Low pass
+            filtered[:, channel] = lfilter(lowPass[0], lowPass[1], filtered[:, channel])
+        if highPass is not None:
+            filtered[:, channel] = lfilter(notchFilter[0], notchFilter[1], filtered[:, channel])
+        if notchFilter is not None:
+            filtered[:, channel] = lfilter(highPass[0], highPass[1], filtered[:, channel])
 
     return filtered
